What is pySpaceGDN?
-------------------

|Travis-ci|\ |ReadTheDocs|\ |Code Health|\ |Coverage Status|\ |License|

pySpaceGDN is an MIT licensed client-side module for interfacing with
the SpaceGDN API over Python. It is heavily documented and unit
tested(100% test coverage - Woot, woot!).

**The documentation is `here`_.**

.. _here: http://pyspacegdn.readthedocs.org/en/latest/

.. |Travis-ci| image:: http://img.shields.io/travis/totokaka/pySpaceGDN.svg?style=flat-square
   :target: https://travis-ci.org/totokaka/pySpaceGDN/
.. |ReadTheDocs| image:: http://img.shields.io/badge/docs-latest-brightgreen.svg?style=flat-square
   :target: http://pyspacegdn.readthedocs.org/en/latest/
.. |Code Health| image:: http://img.shields.io/badge/health-96%-brightgreen.svg?style=flat-square
   :target: https://landscape.io/github/totokaka/pySpaceGDN/master
.. |Coverage Status| image:: http://img.shields.io/coveralls/totokaka/pySpaceGDN.svg?style=flat-square
   :target: https://coveralls.io/r/totokaka/pySpaceGDN?branch=master
.. |License| image:: http://img.shields.io/badge/license-MIT-blue.svg?style=flat-square
   :target: http://opensource.org/licenses/mit-license.php
